Project MoePad
==============

|Build Status|

本程序用于支持@萌娘百科的更（平）新（板）姬在\ `新浪微博 <http://weibo.com/moegirlwiki>`__\ 的自动更新\_(:з”∠)\_

`开始使用 <https://github.com/deloeating/MoeDj/blob/master/docs/Install.md>`__

This is MoePad All in One package.

License: MIT

.. |Build Status| image:: https://travis-ci.org/deloeating/MoeDj.png?branch=master
   :target: https://travis-ci.org/deloeating/MoeDj
